@@ -1,10 +1,8 @@
 #![feature(test)]
-extern crate jsonwebtoken as jwt;
 extern crate test;
-#[macro_use]
-extern crate serde_derive;
 
-use jwt::{decode, encode, Header, Validation};
+use jsonwebtoken::{decode, encode, DecodingKey, EncodingKey, Header, Validation};
+use serde::{Deserialize, Serialize};
 
 #[derive(Debug, PartialEq, Clone, Serialize, Deserialize)]
 struct Claims {
@@ -15,12 +13,15 @@ struct Claims {
 #[bench]
 fn bench_encode(b: &mut test::Bencher) {
     let claim = Claims { sub: "b@b.com".to_owned(), company: "ACME".to_owned() };
+    let key = EncodingKey::from_secret("secret".as_ref());
 
-    b.iter(|| encode(&Header::default(), &claim, "secret".as_ref()));
+    b.iter(|| encode(&Header::default(), &claim, &key));
 }
 
 #[bench]
 fn bench_decode(b: &mut test::Bencher) {
     let token = "eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJzdWIiOiIxMjM0NTY3ODkwIiwibmFtZSI6IkpvaG4gRG9lIiwiYWRtaW4iOnRydWV9.TJVA95OrM7E2cBab30RMHrHDcEfxjoYZgeFONFh7HgQ";
-    b.iter(|| decode::<Claims>(token, "secret".as_ref(), &Validation::default()));
+    let key = DecodingKey::from_secret("secret".as_ref());
+
+    b.iter(|| decode::<Claims>(token, &key, &Validation::default()));
 }
